pub enum ReadErrorKind {
UnterminatedQuote,
TrailingContent,
Io(Error),
InvalidUtf8,
}Expand description
Kinds of errors that can occur when reading CSV data.
Variants
UnterminatedQuote
A quoted field was opened but never closed before end of input.
TrailingContent
Non-delimiter, non-newline content appeared after a closing quote.
Io(Error)
An I/O error from the underlying read source.
InvalidUtf8
The CSV data contains invalid UTF-8.